==> nextcloud-app-deck-1%3a1.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "Personal" : "Personale",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "Create new board" : "Krijo bord të ri",
    "Cancel" : "Anullo",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Details" : "Detajet",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Delete" : "Delete",
    "Add a new stack" : "Shto një raft të ri",
    "Add card" : "Shto kartë",
    "Edit" : "Edito",
    "Due date" : "Data e vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "Attachments" : "Bashkangjitjet",
    "Comments" : "Komentet",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Save" : "Ruaj",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "(group)" : "(grup)",
    "seconds ago" : "sekonda më parë",
    "Archived boards" : "Borde të arkivuara",
    "Shared boards" : "Tabela të shpërndara",
    "Settings" : "Rregullimet",
    "New board title" : "Titull i ri bordi",
    "Share" : "Shpërndaje",
    "Edit board" : "Tabela e editimeve",
    "Archive board" : "Arkivo bordin",
    "Unarchive board" : "Hiq bordin nga arkivi",
    "Delete board" : "Fshij bordin",
    "Board details" : "Detajet e Tabeles "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3a1.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/sq.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Shto paisjen U2F",
    "Personal" : "Personale",
    "Finished" : "Përfunduar",
    "To review" : "Për rishikim",
    "Action needed" : "Nevoitet veprim",
    "Later" : "Më vonë",
    "copy" : "kopjo",
    "To do" : "Për t'u bërë",
    "Doing" : "Duke e bërë",
    "Done" : "Përfunduar",
    "The file was uploaded" : "Skedari u ngarkua",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
    "No file was uploaded" : "S’u ngarkua kartelë",
    "Missing a temporary folder" : "Mungon një dosje e përkohshme",
    "Cancel" : "Anullo",
    "File already exists" : "Skedari ekziston tashmë",
    "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
    "Hide archived cards" : "Fsheh kartat e arkivuara ",
    "Show archived cards" : "Trego kartat e arkivuara",
    "Details" : "Detajet",
    "Sharing" : "Ndarje",
    "Tags" : "Etiketa",
    "Undo" : "Ktheje pas",
    "Can edit" : "Can edit",
    "Can share" : "Mund të ndaj",
    "Delete" : "Delete",
    "Add card" : "Shto kartë",
    "Edit" : "Edito",
    "Title" : "Titulli",
    "Members" : "Anëtar",
    "Upload attachment" : "Ngarko bashkëngjitje",
    "Due date" : "Data e vendosur",
    "Remove due date" : "Hiq datën e mbarimit",
    "Description" : "Përshkrim",
    "Formatting help" : "Ndihmë formatimi",
    "Attachments" : "Bashkangjitjet",
    "Comments" : "Komentet",
    "Select Date" : "Zgjidhni Datën",
    "Modified" : "Modifikuar ",
    "Created" : "U krijua",
    "Save" : "Ruaj",
    "Reply" : "Përgjigju",
    "Update" : "Përditëso",
    "(group)" : "(grup)",
    "seconds ago" : "sekonda më parë",
    "Archived boards" : "Borde të arkivuara",
    "Shared with you" : "E ndarë me ju",
    "Edit board" : "Tabela e editimeve",
    "Board details" : "Detajet e Tabeles ",
    "Today" : "Sot",
    "Tomorrow" : "Nesër",
    "This week" : "Këtë javë"
},
"nplurals=2; plural=(n != 1);");
